==> nom-3.5.2-de-download.zip: nom-3.5.2-de/webhelp/nom-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entireoutputmanagement
//
//	Copyright (c) 2016-2024 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entireoutputmanagement = {
    baseurls: ["../"],
    varname: "entireoutputmanagement",
        tree: [
            { url: "about/about.htm", title: "Über diese Dokumentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Dokumentationskonventionen" },
                  { url: "about/online_information.htm", title: "Online-Informationen und Support" },
                  { url: "about/data_protection.htm", title: "Datenschutz" },
              ]
            },
            { url: "cnf/cnf_content_0010.htm", title: "Konzept und Leistungsumfang" },
            { url: "rnotes/rnotes-over_0001.htm", title: "Release Notes",
              tree: [
                  { url: "rnotes/rnotes_nom352.htm", title: "Entire Output Management Version 3.5.2 Release Notes" },
                  { url: "rnotes/rnotes_nom351.htm", title: "Entire Output Management Version 3.5.1 Release Notes" },
                  { url: "rnotes/rnotes_nom343.htm", title: "Entire Output Management Version 3.4.3 Release Notes" },
              ]
            },
            { url: "inst/overview.htm", title: "Installation und kundenspezifische Anpassung",
              tree: [
                  { url: "inst/InstallMF.htm", title: "Entire Output Management auf Großrechnern installieren und kundenspezifisch anpassen" },
                  { url: "inst/BeforeInstallation.htm", title: "Vor der Installation" },
                  { url: "inst/inst_first.htm", title: "Entire Output Management installieren" },
                  { url: "inst/CompletingInstallation.htm", title: "Installation fertigstellen" },
                  { url: "inst/InstallingOptional.htm", title: "Optionale Merkmale installieren" },
              ]
            },
            { url: "inst_unix/inst-over.htm", title: "Installation und kundenspezifische Anpassung auf UNIX-Plattformen",
              tree: [
                  { url: "inst_unix/inst-sysreq.htm", title: "Systemerfordernisse" },
                  { url: "inst_unix/inst-info.htm", title: "Wichtige Informationen" },
                  { url: "inst_unix/inst-nat.htm", title: "Entire Output Management installieren" },
                  { url: "inst_unix/inst-complete.htm", title: "Installation beenden" },
                  { url: "inst_unix/inst-uninstall.htm", title: "Entire Output Management deinstallieren" },
              ]
            },
            { url: "ug/ug-over_0001.htm", title: "Benutzerhandbuch",
              tree: [
                  { url: "ug/ug_use_0010.htm", title: "Entire Output Management benutzen" },
                  { url: "ug/Help_Facility.htm", title: "Hilfe" },
                  { url: "ug/ug_defr-over_0020.htm", title: "Reports",
                    tree: [
                        { url: "ug/ReportsAllgemein.htm", title: "Allgemeine Informationen zu Reports" },
                        { url: "ug/ug_defroth_0090.htm", title: "Verwaltung der Reports" },
                        { url: "ug/ug_defradd_0070.htm", title: "Attribute eines Reports definieren" },
                        { url: "ug/ug_defrtrac_0080.htm", title: "Report-Verarbeitung schrittweise verfolgen" },
                    ]
                  },
                  { url: "ug/ug_actrp-over_0150.htm", title: "Aktive Reports" },
                  { url: "ug/ug_actrp_general.htm", title: "Allgemeine Informationen zu aktiven Reports",
                    tree: [
                        { url: "ug/ug_actrpmod_0210.htm", title: "Aktive Reports in der Report-Verwaltung" },
                        { url: "ug/ch_abundles_arep.htm", title: "Aktive Reports in einem aktiven Bündel" },
                        { url: "ug/Folders.htm", title: "Verwaltung der Fächer" },
                    ]
                  },
                  { url: "ug/ug_defb_0100.htm", title: "Bündel" },
                  { url: "ug/Bundle_General_Info.htm", title: "Was ist ein Bündel" },
                  { url: "ug/Bundle_Maintenance.htm", title: "Verwaltung der Bündel" },
                  { url: "ug/ch_bundle_add.htm", title: "Attribute eines Bündels definieren" },
                  { url: "ug/Defining_Bundle_Contents.htm", title: "Inhalt eines Bündels verwalten" },
                  { url: "ug/ug_print_0110.htm", title: "Logische Drucker" },
                  { url: "ug/Logical_Printer_What.htm", title: "Was ist ein logischer Drucker?" },
                  { url: "ug/Logical_Printer_Maintenance.htm", title: "Verwaltung der logischen Drucker" },
                  { url: "ug/Distribution_List.htm", title: "Verteiler" },
                  { url: "ug/Distribution_List_GenInfo.htm", title: "Was ist ein Verteiler" },
                  { url: "ug/Distribution_List_Maintenance.htm", title: "Verwaltung der Verteiler" },
                  { url: "ug/ug_deflu_0140.htm", title: "Virtuelle Benutzer anstelle von Verteilern" },
                  { url: "ug/ug_actbd_0240.htm", title: "Aktive Bündel" },
                  { url: "ug/printouts.htm", title: "Druckaufträge" },
              ]
            },
            { url: "messages/overview.htm", title: "About this Documentation",
              tree: [
                  { url: "messages/d0e16.htm", title: "Introduction" },
                  { url: "messages/d0e26.htm", title: "Title of Messages Chapter" },
              ]
            },
            { url: "rm/rm_cmds_0001.htm", title: "Direktkommandos" },
            { url: "sysp/sysp-over_0001.htm", title: "Systemverwaltung",
              tree: [
                  { url: "sysp/sysp_admin_menu.htm", title: "Systemverwaltung aufrufen" },
                  { url: "sysp/sysp_sysdef_0020.htm", title: "NOM-Standardwerte verwalten" },
                  { url: "sysp/sysp_sysuser_0030.htm", title: "Benutzer verwalten" },
                  { url: "sysp/sysp_syscopy_0040.htm", title: "Benutzer-Definitionen aus Natural Security kopieren" },
                  { url: "sysp/sysp_syscal_0050.htm", title: "Kalender verwalten" },
                  { url: "sysp/sysp_sysprin_0060.htm", title: "Physische Drucker verwalten" },
                  { url: "sysp/sysp_sysmon_0070.htm", title: "Monitor-Verwaltung" },
                  { url: "sysp/sysp_sysarch_0080.htm", title: "Archivierung starten" },
                  { url: "sysp/sysp_sysrev_0090.htm", title: "Reaktivierung starten" },
                  { url: "sysp/sysp_syscond_0100.htm", title: "Verdichtung starten" },
                  { url: "sysp/sysp_arch_0130.htm", title: "Archivverwaltung" },
                  { url: "sysp/Separator_Pages.htm", title: "Trennblätter" },
                  { url: "sysp/Us_Sep_Rout.htm", title: "Benutzerroutinen" },
                  { url: "sysp/PrinterExits.htm", title: "Drucker-Exits" },
                  { url: "sysp/APIs.htm", title: "Anwendungsprogrammierungsschnittstellen (APIs)" },
                  { url: "sysp/binarydocuments.htm", title: "Umgebungen für binäre Dokumente einrichten" },
                  { url: "sysp/sysp_trs_0150.htm", title: "Objekte in eine andere Umgebung übertragen" },
                  { url: "sysp/TransferEnvironment.htm", title: "Gesamte Umgebung übertragen" },
                  { url: "sysp/NOMVPRNTmanagement.htm", title: "VTAM NOMVPRNT-Verwaltung" },
                  { url: "sysp/AdabasVista.htm", title: "Adabas Vista benutzen" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entireoutputmanagement });

==> nom-3.5.3-de-download.zip: nom-3.5.3-de/webhelp/nom-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entireoutputmanagement
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entireoutputmanagement = {
    baseurls: ["../"],
    varname: "entireoutputmanagement",
        tree: [
            { url: "about/about.htm", title: "Über diese Dokumentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Dokumentationskonventionen" },
                  { url: "about/online_information.htm", title: "Online-Informationen und Support" },
                  { url: "about/data_protection.htm", title: "Datenschutz" },
              ]
            },
            { url: "cnf/cnf_content_0010.htm", title: "Konzept und Leistungsumfang" },
            { url: "rnotes/rnotes-over_0001.htm", title: "Entire Output Management Version 3.5.3 Freigabemitteilung (Release Notes)" },
            { url: "inst/overview.htm", title: "Installation und kundenspezifische Anpassung",
              tree: [
                  { url: "inst/InstallMF.htm", title: "Entire Output Management auf Großrechnern installieren und kundenspezifisch anpassen" },
                  { url: "inst/BeforeInstallation.htm", title: "Vor der Installation" },
                  { url: "inst/inst_first.htm", title: "Entire Output Management installieren" },
                  { url: "inst/CompletingInstallation.htm", title: "Installation fertigstellen" },
                  { url: "inst/InstallingOptional.htm", title: "Optionale Merkmale installieren" },
              ]
            },
            { url: "inst_unix/inst-over.htm", title: "Installation und kundenspezifische Anpassung auf UNIX-Plattformen",
              tree: [
                  { url: "inst_unix/inst-sysreq.htm", title: "Systemerfordernisse" },
                  { url: "inst_unix/inst-info.htm", title: "Wichtige Informationen" },
                  { url: "inst_unix/inst-nat.htm", title: "Entire Output Management installieren" },
                  { url: "inst_unix/inst-complete.htm", title: "Installation beenden" },
                  { url: "inst_unix/inst-uninstall.htm", title: "Entire Output Management deinstallieren" },
              ]
            },
            { url: "ug/ug-over_0001.htm", title: "Benutzerhandbuch",
              tree: [
                  { url: "ug/ug_use_0010.htm", title: "Entire Output Management benutzen" },
                  { url: "ug/Help_Facility.htm", title: "Hilfe" },
                  { url: "ug/ug_defr-over_0020.htm", title: "Reports",
                    tree: [
                        { url: "ug/ReportsAllgemein.htm", title: "Allgemeine Informationen zu Reports" },
                        { url: "ug/ug_defroth_0090.htm", title: "Verwaltung der Reports" },
                        { url: "ug/ug_defradd_0070.htm", title: "Attribute eines Reports definieren" },
                        { url: "ug/ug_defrtrac_0080.htm", title: "Report-Verarbeitung schrittweise verfolgen" },
                    ]
                  },
                  { url: "ug/ug_actrp-over_0150.htm", title: "Aktive Reports" },
                  { url: "ug/ug_actrp_general.htm", title: "Allgemeine Informationen zu aktiven Reports",
                    tree: [
                        { url: "ug/ug_actrpmod_0210.htm", title: "Aktive Reports in der Report-Verwaltung" },
                        { url: "ug/ch_abundles_arep.htm", title: "Aktive Reports in einem aktiven Bündel" },
                        { url: "ug/Folders.htm", title: "Verwaltung der Fächer" },
                    ]
                  },
                  { url: "ug/ug_defb_0100.htm", title: "Bündel" },
                  { url: "ug/Bundle_General_Info.htm", title: "Was ist ein Bündel" },
                  { url: "ug/Bundle_Maintenance.htm", title: "Verwaltung der Bündel" },
                  { url: "ug/ch_bundle_add.htm", title: "Attribute eines Bündels definieren" },
                  { url: "ug/Defining_Bundle_Contents.htm", title: "Inhalt eines Bündels verwalten" },
                  { url: "ug/ug_print_0110.htm", title: "Logische Drucker" },
                  { url: "ug/Logical_Printer_What.htm", title: "Was ist ein logischer Drucker?" },
                  { url: "ug/Logical_Printer_Maintenance.htm", title: "Verwaltung der logischen Drucker" },
                  { url: "ug/Distribution_List.htm", title: "Verteiler" },
                  { url: "ug/Distribution_List_GenInfo.htm", title: "Was ist ein Verteiler" },
                  { url: "ug/Distribution_List_Maintenance.htm", title: "Verwaltung der Verteiler" },
                  { url: "ug/ug_deflu_0140.htm", title: "Virtuelle Benutzer anstelle von Verteilern" },
                  { url: "ug/ug_actbd_0240.htm", title: "Aktive Bündel" },
                  { url: "ug/printouts.htm", title: "Druckaufträge" },
              ]
            },
            { url: "messages/overview.htm", title: "About this Documentation",
              tree: [
                  { url: "messages/d0e16.htm", title: "Introduction" },
                  { url: "messages/d0e26.htm", title: "Title of Messages Chapter" },
              ]
            },
            { url: "rm/rm_cmds_0001.htm", title: "Direktkommandos" },
            { url: "sysp/sysp-over_0001.htm", title: "Systemverwaltung",
              tree: [
                  { url: "sysp/sysp_admin_menu.htm", title: "Systemverwaltung aufrufen" },
                  { url: "sysp/sysp_sysdef_0020.htm", title: "NOM-Standardwerte verwalten" },
                  { url: "sysp/sysp_sysuser_0030.htm", title: "Benutzer verwalten" },
                  { url: "sysp/sysp_syscopy_0040.htm", title: "Benutzer-Definitionen aus Natural Security kopieren" },
                  { url: "sysp/sysp_syscal_0050.htm", title: "Kalender verwalten" },
                  { url: "sysp/sysp_sysprin_0060.htm", title: "Physische Drucker verwalten" },
                  { url: "sysp/sysp_sysmon_0070.htm", title: "Monitor-Verwaltung" },
                  { url: "sysp/sysp_sysarch_0080.htm", title: "Archivierung starten" },
                  { url: "sysp/sysp_sysrev_0090.htm", title: "Reaktivierung starten" },
                  { url: "sysp/sysp_syscond_0100.htm", title: "Verdichtung starten" },
                  { url: "sysp/sysp_arch_0130.htm", title: "Archivverwaltung" },
                  { url: "sysp/Separator_Pages.htm", title: "Trennblätter" },
                  { url: "sysp/Us_Sep_Rout.htm", title: "Benutzerroutinen" },
                  { url: "sysp/PrinterExits.htm", title: "Drucker-Exits" },
                  { url: "sysp/APIs.htm", title: "Anwendungsprogrammierungsschnittstellen (APIs)" },
                  { url: "sysp/binarydocuments.htm", title: "Umgebungen für binäre Dokumente einrichten" },
                  { url: "sysp/sysp_trs_0150.htm", title: "Objekte in eine andere Umgebung übertragen" },
                  { url: "sysp/TransferEnvironment.htm", title: "Gesamte Umgebung übertragen" },
                  { url: "sysp/NOMVPRNTmanagement.htm", title: "VTAM NOMVPRNT-Verwaltung" },
                  { url: "sysp/AdabasVista.htm", title: "Adabas Vista benutzen" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entireoutputmanagement });
